package com.gic.auth.web.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.gic.auth.constant.MenuLevelConstants;
import org.apache.dubbo.rpc.RpcContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.MenuDTO;
import com.gic.auth.qo.MenuListQO;
import com.gic.auth.service.MenuApiService;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.dto.StoreGroupDTO;

@RestController
public class MenuController {
    @Autowired
    private MenuApiService menuApiService;

    @RequestMapping("login-user-menu")
    public RestResponse loginUserMenu(Integer currentMenu){
        Integer userId = UserDetailUtils.getUserDetail().getUserId();
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        System.out.println(JSON.toJSONString(RpcContext.getContext().getAttachments()));
        ServiceResponse<List<MenuDTO>> userMenu = this.menuApiService.getUserMenu(userId, enterpriseId, currentMenu);
        if(userMenu.isSuccess()){
            return RestResponse.success(userMenu.getResult());
        }
        return EnterpriseRestResponse.failure(userMenu);
    }

    /**
     * 新增GIC页面
     * @Title: saveGICPage 
     * @Description:
      * @author guojuxing
     * @param menuDTO 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/save-gic-page")
    public RestResponse saveGICPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.saveGICPage(menuDTO));
    }

    @RequestMapping("/update-gic-page")
    public RestResponse updateGICPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.updateGICPage(menuDTO));
    }

    @RequestMapping("/delete-menu")
    public RestResponse deleteMenu(Integer menuId) {
        return ResultControllerUtils.commonResult(menuApiService.deleteMenu(menuId));
    }
    /**
     * 新增gic子页面
     * @Title: saveGICChildPage 
     * @Description:
      * @author guojuxing
     * @param menuDTO 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/save-gic-child-page")
    public RestResponse saveGICChildPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.saveGICChildPage(menuDTO));
    }
    @RequestMapping("/update-gic-child-page")
    public RestResponse updateGICChildPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.updateGICChildPage(menuDTO));
    }

    /**
     * 编辑应用页面
     * @Title: updateAppPage 
     * @Description:
      * @author guojuxing
     * @param menuDTO 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/update-app-page")
    public RestResponse updateAppPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.updateAppPage(menuDTO));
    }

    /**
     * 查询列表数据
     * @Title: updateAppPage 
     * @Description:
      * @author guojuxing
     * @param params 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/list-menu-tree")
    public RestResponse listMenuTree(MenuListQO params) {
        ServiceResponse<List<MenuDTO>> result = menuApiService.listMenuTree(params);
        if (result.isSuccess()) {
            return RestResponse.success(changeListToTree(MenuLevelConstants.FIRST_LEVEL_PARENT_ID, result.getResult()));
        }
        return EnterpriseRestResponse.failure(result);
    }
    /**
     * 查询页面下面的权限项列表数据
     * @Title: listMenuRole 
     * @Description:
      * @author guojuxing
     * @param parentId 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/list-menu-role")
    public RestResponse listMenuRole(Integer parentId) {
        return ResultControllerUtils.commonResult(menuApiService.listMenuRoleByParentId(parentId));
    }

    public static List<Map<String, Object>> changeListToTree(int storeGroupId, List<MenuDTO> list) {
        List<Map<String, Object>> result = new ArrayList<>();
        if (list != null) {
            for (MenuDTO menuDTO : list) {
                if (storeGroupId == menuDTO.getParentId() && menuDTO.getIsShow().intValue() == 1) {
                    Map<String, Object> data = new HashMap<>(16);
                    data.put("menuId", menuDTO.getMenuId());
                    data.put("menuName", menuDTO.getMenuName());
                    data.put("project", menuDTO.getProject());
                    data.put("sort", menuDTO.getSort());
                    data.put("menuCode", menuDTO.getMenuCode());
                    data.put("parentCode", menuDTO.getParentCode());
                    data.put("menuVersion", menuDTO.getMenuVersion());
                    List<Map<String, Object>> children = changeListToTree(menuDTO.getMenuId(), list);
                    if (children == null || children.size() < 1) {
                        data.put("children", null);
                    } else {
                        data.put("children", children);
                    }
                    result.add(data);
                }
            }
        }
        return result;
    }
}
